{# TEMPLATE VAR SETTINGS #}
{%- set url_root = pathto('', 1) %}
{%- if url_root == '#' %}{% set url_root = '' %}{% endif %}
{%- if not embedded and docstitle %}
  {%- set titlesuffix = " &mdash; "|safe + docstitle|e %}
{%- else %}
  {%- set titlesuffix = "" %}
{%- endif %}
  
{%- macro css() %}
    <!-- <link rel="stylesheet" href="{{ pathto('_static/' + style, 1) }}" type="text/css" /> -->
     <link rel="stylesheet" href="{{ pathto('_static/basic.css', 1) }}" type="text/css" />
    <link rel="stylesheet" href="{{ pathto('_static/pygments.css', 1) }}" type="text/css" />
    {%- for cssfile in css_files %}
    <link rel="stylesheet" href="{{ pathto(cssfile, 1) }}" type="text/css" />
    {%- endfor %}
    {% for cssfile in extra_css_files %}
      <link rel="stylesheet" href="{{ pathto(cssfile, 1) }}" type="text/css" />
    {% endfor %}
{%- endmacro %}

{%- macro badges() %}
    {% for badge in theme_badges %}
      {{ badge }}
    {% endfor %}
{%- endmacro %}


<!DOCTYPE html>
<!--[if IE 8]><html class="no-js lt-ie9" lang="en" > <![endif]-->
<!--[if gt IE 8]><!--> <html lang="en" > <!--<![endif]-->
<head>
  <meta charset="utf-8">
  {{ metatags }}  
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  {% block htmltitle %}
  <title>{{ title|striptags|e }}{{ titlesuffix }}</title>
  {% endblock %}       

  {# FAVICON #}
  {% if favicon %}
    <link rel="shortcut icon" href="{{ pathto('_static/' + favicon, 1) }}"/>
  {% endif %}
 
  {# Keep modernizr in head - http://modernizr.com/docs/#installing #}
  <!-- <script src="{{ pathto('_static/js/modernizr.min.js', 1) }}"></script> -->


</head>

<body role="document">


  <div id="mariana-page" class="ui grid ">
    

    <div class="sixteen wide column mariana-header">
        <h1>{{ project }}</h1>

    </div>

    <!-- Menu --> 
    <div class="four wide column ">
      
        {# Sticky Left Nav #}
        <!--<div class="left ui rail"> ui sticky-->

          <div class="mariana-menu ">

            <!-- Logo -->
            {%- if theme_left_logo %}
            <div class="ui segment">
              <img src="{{ pathto('_static/%s' % theme_left_logo, 1) }}" style="width:100%" />
            </div>
            {%- endif %}        

            <!-- Badges -->
            {%- if theme_badges %}
            <div class="badges">
            {{ badges() }}
            </div>
            {%- endif %}

            <!-- TOC -->
            <div id="toc">
            {% block menu %}
              {% set global_toc = toctree(maxdepth=theme_navigation_depth|int, collapse=False, includehidden=True,titles_only=False) %}
              
              {{ global_toc }} 
           
               <!-- Local TOC -->
              <!--<div class="local-toc">{{ toc }}</div>-->
            {% endblock %}
            </div>

          </div>

        <!--</div> -->

    </div>

    <!-- Page content -->
    <div class="twelve wide column">
      
      <div id="mariana-page-content">

        {# Breadcrumbs #}
        <div id="breadcrumbs">
          {% include "breadcrumbs.html" %}
        </div>

        <!-- class="ui segment" -->
        <div  id="page-body" >


          

            


            <div role="main" class="document" itemscope="itemscope" itemtype="http://schema.org/Article">
               <div itemprop="articleBody">
                {% block body %}{% endblock %}
               </div>
               <div class="articleComments">
                {% block comments %}{% endblock %}
               </div>


            </div>
            <!-- Load extra scripts here -->
              {{ css() }}
              {# Semantic #}
              <script src="{{ pathto('_static/js/jquery-3.1.1.min.js', 1) }}"></script>
              <script src="{{ pathto('_static/semantic/semantic.min.js', 1) }}"></script>
              <link rel="stylesheet" href="{{ pathto('_static/semantic/semantic.min.css', 1) }}" type="text/css" />

              <script src="{{ pathto('_static/semantic/components/sticky.min.js', 1) }}"></script>
              <link rel="stylesheet" href="{{ pathto('_static/semantic/components/sticky.min.css', 1) }}" type="text/css" />

              <script src="{{ pathto('_static/js/highlight.min.js', 1) }}"></script>

              {% if theme_highlightjs_style  %}
              <!--<link rel="stylesheet" href="{{ pathto('_static/css/highlight-styles/'+theme_highlightjs_style+'.css', 1) }}" type="text/css" /> -->
              {% else %}
              <!-- <link rel="stylesheet" href="{{ pathto('_static/css/highlight-styles/default.css', 1) }}" type="text/css" /> -->
              {% endif %}
                

              {## SNAP SVG ##}
              <script src="{{ pathto('_static/js/snap.svg-min.js', 1) }}"></script>

              {# PDFJS #}
              <!-- <script src="{{ pathto('_static/external/pdfjs-1.8.170/build/pdf.js', 1) }}"></script> -->
              <script src="{{ pathto('_static/external/pdfjs-2.13.216/build/pdf.js', 1) }}"></script>
              <script src="{{ pathto('_static/external/pdfjs-2.13.216/build/pdf.worker.js', 1) }}"></script>

              {# Wavedrom #}
              <script src="{{ pathto('_static/external/wavedrom/skins/default.js', 1) }}"></script>
              <script src="{{ pathto('_static/external/wavedrom/wavedrom.min.js', 1) }}"></script>

              <link rel="stylesheet" href="{{ pathto('_static/css/mariana.css', 1) }}" type="text/css" />
              <script src="{{ pathto('_static/js/mariana.js', 1) }}"></script>

            {% include "footer.html" %}

            

        </div>
        <!-- EOF page body -->

      </div>


    </div>


     <!-- Header -->
    <!-- ###### -->
    <!-- <div id="header">
      <h1>{{ project }}</h1>
      
    </div>
    -->

     
    


  {% block extrabody %} {% endblock %}
  </div>
  <!-- EOF Page container -->

 

</body>
</html>
