{# Support for Sphinx 1.3+ page_source_suffix, but don't break old builds. #}

{% if page_source_suffix %}
{% set suffix = page_source_suffix %}
{% else %}
{% set suffix = source_suffix %}
{% endif %}

{% if meta is defined and meta is not none %}
{% set check_meta = True %}
{% else %}
{% set check_meta = False %}
{% endif %}

{% if check_meta and 'github_url' in meta %}
{% set display_github = True %}
{% endif %}

{% if check_meta and 'bitbucket_url' in meta %}
{% set display_bitbucket = True %}
{% endif %}

{% if check_meta and 'gitlab_url' in meta %}
{% set display_gitlab = True %}
{% endif %} 

<div role="navigation"  aria-label="breadcrumbs navigation">

  <div class="ui large breadcrumb"> 
    {% block breadcrumbs %}
      <a href="{{ pathto(master_doc) }}">Home</a> 
      {% for doc in parents %}
        <i class="right chevron icon divider"></i>
        <a href="{{ doc.link|e }}" class="section">{{ doc.title }}</a> 
      {% endfor %}
      <i class="right chevron icon divider"></i>
      {{ title }}
    {% endblock %} 
  </div>       
 
  {% if (theme_prev_next_buttons_location == 'top' or theme_prev_next_buttons_location == 'both') and (next or prev) %}
  <div class="rst-breadcrumbs-buttons" role="navigation" aria-label="breadcrumb navigation">
      {% if next %}
        <a href="{{ next.link|e }}" class="btn btn-neutral float-right" title="{{ next.title|striptags|e }}" accesskey="n">Next <span class="fa fa-arrow-circle-right"></span></a>
      {% endif %}
      {% if prev %}
        <a href="{{ prev.link|e }}" class="btn btn-neutral" title="{{ prev.title|striptags|e }}" accesskey="p"><span class="fa fa-arrow-circle-left"></span> Previous</a>
      {% endif %}
  </div>
  {% endif %}
  <hr/>
</div>
