body {
	/*width: 100%;
	margin: 40px;*/
	font-size: 14px;
}

footer {
	margin-top:20px;
}

/** Page container */
#mariana-page {

	margin: 20px;
	font-size: 16px !important;
	line-height: 24px !important;

}

#mariana-page ul {
	font-size: 16px !important;
}

#mariana-page .menu {
	font-size: 14px !important;
}

#mariana-page .ui.segment p {
	font-size: 16px !important;
	line-height: 24px !important;
}

#mariana-page .header {
	/*font-size: smaller;*/


}

#mariana-page h1 {
	margin-top: 10px;
}

#mariana-page h2 {
	margin-top: 10px;
}

#mariana-page h3 {
	margin-top: 10px;
}

#mariana-page h4 {
	margin-top: 10px;
}

/** Menu and Content**/
.contents.local.topic {
	margin-bottom: 10px;
	margin-top: 10px;
	border: none;
}

.contents.local.topic .simple {
	margin-left: 0px;
}



/** IMG and Figure **/

#mariana-page img {
	max-width: 100%;
}

#mariana-page div.figure {
	
	text-align:center;
	margin-left: auto;
	margin-right: auto;
	margin-bottom: 20px;
	margin-top: 20px;
	
}

#mariana-page .figure span.caption-text {
	
	font-style: italic;
	
	
	/*background-color: lightgray;*/
}

/** Two content container */
#mariana-page .two-contents {
	margin-left: auto;
	margin-right: auto;
	display: table;
	margin-bottom: 20px;
}



#mariana-page .two-contents div  {
	/*float: right;
	display: inline-block;
	position: relative;*/
	display: table-cell !important;
    vertical-align: middle;
}

/** Rubric **/
#mariana-page p.rubric {
	font-weight: bold;
	border-bottom: 1px solid gray;
}

/** SIDE BAR **/

#mariana-page .ui.sidebar {
	background-color: lightgray;
}

#mariana-page .ui.vertical.menu {
	width: 100%;
} 
#mariana-page .ui.vertical.menu .item {
	width: 100%;
	padding-bottom: 0px;
}

#mariana-page .ui.menu.item {
	width: 100%;
	margin-bottom: 2px !important;
	padding-bottom: 2px !important;
}

/** Sections **/
#mariana-page .section {
	margin-bottom: 20px;
}

/** SVG Stuff **/

/* Hide SVG per default, JS will display when ok */
#mariana-page .odfi.svg {
	visibility: hidden;
}

/* Hide Header Links */
#mariana-page .headerlink {
	display: none;
}

/** PDF **/
#mariana-page .pdfjs {
	width:60%;
}

/** Block quotes **/
blockquote {


	
	
}

/** Steps Support **/
#mariana-page-content .steps .step {
	width: 80%;
	margin-left: auto;
	margin-right: auto;
	margin-bottom: 10px;
}
#mariana-page-content .steps .step .picture img {
	width: 100%;
}

/** Code **/
#mariana-page-content .highlighttable .linenos {
	width: 20px;
	color: lightgray;
	/*line-height: 120%;*/
}
#mariana-page-content .highlight {
	background-color: white;
}
#mariana-page-content .highlight pre {
	font-family: 'Consolas', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', monospace;
    font-size: 13px;
    letter-spacing: 0.015em;
    /*line-height: 120%;*/
    padding: 0.5em;
    border: 1px solid #ccc;
    border-radius: 2px;
    background-color: #f8f8f8;
}


#mariana-page .badges {

	margin: 5px;
	vertical-align: middle;

}

#mariana-page .badges a {

	margin-left: 5px;
	margin-top: auto;
	margin-bottom: auto;
	vertical-align: middle;

}

#mariana-page .admonition {
	padding: 10px;
	padding-left: 20px;
}